==> db-client-java-5.4.3-sources.jar: com/eventstore/dbclient/proto/gossip/GossipGrpc.java <==
package com.eventstore.dbclient.proto.gossip;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.61.1)",
    comments = "Source: gossip.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class GossipGrpc {

  private GossipGrpc() {}

  public static final java.lang.String SERVICE_NAME = "event_store.client.gossip.Gossip";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty,
      com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> getReadMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Read",
      requestType = com.eventstore.dbclient.proto.shared.Shared.Empty.class,
      responseType = com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty,
      com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> getReadMethod() {
    io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty, com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> getReadMethod;
    if ((getReadMethod = GossipGrpc.getReadMethod) == null) {
      synchronized (GossipGrpc.class) {
        if ((getReadMethod = GossipGrpc.getReadMethod) == null) {
          GossipGrpc.getReadMethod = getReadMethod =
              io.grpc.MethodDescriptor.<com.eventstore.dbclient.proto.shared.Shared.Empty, com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Read"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.eventstore.dbclient.proto.shared.Shared.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo.getDefaultInstance()))
              .setSchemaDescriptor(new GossipMethodDescriptorSupplier("Read"))
              .build();
        }
      }
    }
    return getReadMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static GossipStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GossipStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GossipStub>() {
        @java.lang.Override
        public GossipStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GossipStub(channel, callOptions);
        }
      };
    return GossipStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static GossipBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GossipBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GossipBlockingStub>() {
        @java.lang.Override
        public GossipBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GossipBlockingStub(channel, callOptions);
        }
      };
    return GossipBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static GossipFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GossipFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GossipFutureStub>() {
        @java.lang.Override
        public GossipFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GossipFutureStub(channel, callOptions);
        }
      };
    return GossipFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void read(com.eventstore.dbclient.proto.shared.Shared.Empty request,
        io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getReadMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service Gossip.
   */
  public static abstract class GossipImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return GossipGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service Gossip.
   */
  public static final class GossipStub
      extends io.grpc.stub.AbstractAsyncStub<GossipStub> {
    private GossipStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GossipStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GossipStub(channel, callOptions);
    }

    /**
     */
    public void read(com.eventstore.dbclient.proto.shared.Shared.Empty request,
        io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getReadMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service Gossip.
   */
  public static final class GossipBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<GossipBlockingStub> {
    private GossipBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GossipBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GossipBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo read(com.eventstore.dbclient.proto.shared.Shared.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getReadMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service Gossip.
   */
  public static final class GossipFutureStub
      extends io.grpc.stub.AbstractFutureStub<GossipFutureStub> {
    private GossipFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GossipFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GossipFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> read(
        com.eventstore.dbclient.proto.shared.Shared.Empty request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getReadMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_READ = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_READ:
          serviceImpl.read((com.eventstore.dbclient.proto.shared.Shared.Empty) request,
              (io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getReadMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              com.eventstore.dbclient.proto.shared.Shared.Empty,
              com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo>(
                service, METHODID_READ)))
        .build();
  }

  private static abstract class GossipBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    GossipBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.eventstore.dbclient.proto.gossip.GossipOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("Gossip");
    }
  }

  private static final class GossipFileDescriptorSupplier
      extends GossipBaseDescriptorSupplier {
    GossipFileDescriptorSupplier() {}
  }

  private static final class GossipMethodDescriptorSupplier
      extends GossipBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    GossipMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (GossipGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new GossipFileDescriptorSupplier())
              .addMethod(getReadMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> db-client-java-5.4.4-sources.jar: com/eventstore/dbclient/proto/gossip/GossipGrpc.java <==
package com.eventstore.dbclient.proto.gossip;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.71.0)",
    comments = "Source: gossip.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class GossipGrpc {

  private GossipGrpc() {}

  public static final java.lang.String SERVICE_NAME = "event_store.client.gossip.Gossip";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty,
      com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> getReadMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Read",
      requestType = com.eventstore.dbclient.proto.shared.Shared.Empty.class,
      responseType = com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty,
      com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> getReadMethod() {
    io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty, com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> getReadMethod;
    if ((getReadMethod = GossipGrpc.getReadMethod) == null) {
      synchronized (GossipGrpc.class) {
        if ((getReadMethod = GossipGrpc.getReadMethod) == null) {
          GossipGrpc.getReadMethod = getReadMethod =
              io.grpc.MethodDescriptor.<com.eventstore.dbclient.proto.shared.Shared.Empty, com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Read"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.eventstore.dbclient.proto.shared.Shared.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo.getDefaultInstance()))
              .setSchemaDescriptor(new GossipMethodDescriptorSupplier("Read"))
              .build();
        }
      }
    }
    return getReadMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static GossipStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GossipStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GossipStub>() {
        @java.lang.Override
        public GossipStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GossipStub(channel, callOptions);
        }
      };
    return GossipStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports all types of calls on the service
   */
  public static GossipBlockingV2Stub newBlockingV2Stub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GossipBlockingV2Stub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GossipBlockingV2Stub>() {
        @java.lang.Override
        public GossipBlockingV2Stub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GossipBlockingV2Stub(channel, callOptions);
        }
      };
    return GossipBlockingV2Stub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static GossipBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GossipBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GossipBlockingStub>() {
        @java.lang.Override
        public GossipBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GossipBlockingStub(channel, callOptions);
        }
      };
    return GossipBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static GossipFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GossipFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GossipFutureStub>() {
        @java.lang.Override
        public GossipFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GossipFutureStub(channel, callOptions);
        }
      };
    return GossipFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void read(com.eventstore.dbclient.proto.shared.Shared.Empty request,
        io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getReadMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service Gossip.
   */
  public static abstract class GossipImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return GossipGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service Gossip.
   */
  public static final class GossipStub
      extends io.grpc.stub.AbstractAsyncStub<GossipStub> {
    private GossipStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GossipStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GossipStub(channel, callOptions);
    }

    /**
     */
    public void read(com.eventstore.dbclient.proto.shared.Shared.Empty request,
        io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getReadMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service Gossip.
   */
  public static final class GossipBlockingV2Stub
      extends io.grpc.stub.AbstractBlockingStub<GossipBlockingV2Stub> {
    private GossipBlockingV2Stub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GossipBlockingV2Stub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GossipBlockingV2Stub(channel, callOptions);
    }

    /**
     */
    public com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo read(com.eventstore.dbclient.proto.shared.Shared.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getReadMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do limited synchronous rpc calls to service Gossip.
   */
  public static final class GossipBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<GossipBlockingStub> {
    private GossipBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GossipBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GossipBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo read(com.eventstore.dbclient.proto.shared.Shared.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getReadMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service Gossip.
   */
  public static final class GossipFutureStub
      extends io.grpc.stub.AbstractFutureStub<GossipFutureStub> {
    private GossipFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GossipFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GossipFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo> read(
        com.eventstore.dbclient.proto.shared.Shared.Empty request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getReadMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_READ = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_READ:
          serviceImpl.read((com.eventstore.dbclient.proto.shared.Shared.Empty) request,
              (io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getReadMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              com.eventstore.dbclient.proto.shared.Shared.Empty,
              com.eventstore.dbclient.proto.gossip.GossipOuterClass.ClusterInfo>(
                service, METHODID_READ)))
        .build();
  }

  private static abstract class GossipBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    GossipBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.eventstore.dbclient.proto.gossip.GossipOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("Gossip");
    }
  }

  private static final class GossipFileDescriptorSupplier
      extends GossipBaseDescriptorSupplier {
    GossipFileDescriptorSupplier() {}
  }

  private static final class GossipMethodDescriptorSupplier
      extends GossipBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    GossipMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (GossipGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new GossipFileDescriptorSupplier())
              .addMethod(getReadMethod())
              .build();
        }
      }
    }
    return result;
  }
}
